# libpytools

Módulo para exemplificar a construção de projetos Python.

Exemplo de como contribuir com projetos de código aberto

Link [libpytools](https://github.com/FerreiraMa/libpytools/)

![fluxo de trabalho](https://github.com/FerreiraMa/libpytools/actions/workflows/python-app.yml/badge.svg)
[![Updates](https://pyup.io/repos/github/FerreiraMa/libpytools/shield.svg)](https://pyup.io/repos/github/FerreiraMa/libpytools/)
[![Python 3](https://pyup.io/repos/github/FerreiraMa/libpytools/python-3-shield.svg)](https://pyup.io/repos/github/FerreiraMa/libpytools/)


Suporta versão 3 do Python

Para instalar:

```console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements-dev.txt
```

Para conferir qualidade de códigos:

```console
flake8

```

Tópicos a serem abordados:
1. Git
2. Virtualenv
3. Pip